# BMI-visualisation

bmiviz is a tool that visualize transition and composition ratio of adults' BMI (body mess index) in each country. 

It scrapes the following CSV file (9.3 MB) to obtain BMI data.

https://ncdrisc.org/downloads/bmi/NCD_RisC_Lancet_2017_BMI_age_standardised_country.csv

## How to install bmiviz

### Install bmiviz

$ pip install bmiviz

## How to run bmiviz

### Visualize BMI data

$ bmiviz Japan

<img src=https://github.com/MDchor/BMI-visualisation/raw/main/Japan.png>

### Show available countries

$ bmiviz
